@@ -21,23 +21,28 @@
 mod memory;
 
 pub use memory::{MemoryStore, MemoryStoreConfig};
+use thiserror::Error;
 
-use crate::K_VALUE;
 use super::*;
+use crate::K_VALUE;
 use std::borrow::Cow;
 
 /// The result of an operation on a `RecordStore`.
 pub type Result<T> = std::result::Result<T, Error>;
 
 /// The possible errors of a `RecordStore` operation.
-#[derive(Debug)]
+#[derive(Error, Debug, Clone)]
 pub enum Error {
     /// The store is at capacity w.r.t. the total number of stored records.
+    #[error("the store cannot contain any more records")]
     MaxRecords,
-    /// The store is at capacity w.r.t. the total number of stored keys for
-    /// provider records.
+
+    /// The store is at capacity w.r.t. the total number of stored provider records.
+    #[error("the store cannot contain any more provider records")]
     MaxProvidedKeys,
-    /// The value of a record to be stored is too large.
+
+    /// The store cannot store this value because it is too large.
+    #[error("the value is too large to be stored")]
     ValueTooLarge,
 }
 
@@ -92,4 +97,3 @@ pub trait RecordStore<'a> {
     /// Removes a provider record from the store.
     fn remove_provider(&'a mut self, k: &Key, p: &PeerId);
 }
-
